C     ******************************************************************
              SUBROUTINE GRAPH2 (R, XLEFT, XRIGHT, TTC, SAMPLE)
C     ******************************************************************
C     *                                                                *
C     * THIS SUBROUTINE ESTABLISHES A CONVERSATIONAL INTERACTION WITH  *
C     * THE USER, OFFERING HIM/HER OPTIONS FOR DISPLAYING THE          *
C     * RAW-DATA GRAPHICALLY FOR A GIVEN PATTERN, PRINTING A HARD-COPY *
C     * OF THE GRAPH, OR MANIPULATING THE SCALE OF THE GRAPH FOR       *
C     * DETAILED EXAMINATION.                                          *
C     *                                                                *
C     * THIS CODE WAS DEVELOPED FOR THE CLAY-APD PROJECT BY            *
C     *            THE PENNSYLVANIA STATE UNIVERSITY                   *
C     *              MATERIALS RESEARCH LABORATORY                     *
C     *                UNIVERSITY PARK, PA 16802                       *
C     * WHICH HOLDS FULL PROPERTY RIGHTS OVER IT. THEREFORE, THIS      *
C     * PROGRAM CANNOT BE USED, COPIED OR STORED BY ANY MEANS WITHOUT  *
C     * THE WRITTEN PERMISSION OF THE OWNER. GRAPHIC CALLS ARE DEC     *
C     * REMOTE GRAPHICS INSTRUCTION SET - REGIS.                       *
C     *                         *  *  *                                *
C     *       THIS IS AN ADAPTATION OF THE "GRAPH1" SUBROUTINE.        *
C     *                WRITTEN BY ALEXANDRE SCHEIBLE                   *
C     *                        JUL. 1985                               *
C     *                                                                *
C     ******************************************************************
C
C
C     ==================================================================
C     |                  GLOSSARY OF VARIABLES                         |
C     |================================================================|
C     | CONVENTIONS:                                                   |
C     |   1.) TYPE:  B=BOOLEAN, C=CHARACTER, I=INTEGER, R=REAL         |
C     |   2.) STRUCTURE:  ARR=ARRAY, MTRX=MATRIX, SCLR=SCALAR          |
C     |   3.) SCOPE:  A=ACTUAL PAR., F=FORMAL PAR., G=GLOBAL, L=LOCAL  |
C     |----------------------------------------------------------------|
C     |  VAR   |TYP|STRCT | DIM  |SCP| DESCRIPTION                     |
C     |--------|---|------|------|---|---------------------------------|
C     | BEGIN  | B | SCLR |  1   | L | INDICATES WHETHER THE EXECUTION |
C     |        |   |      |      |   | STATUS AT A PARTICULAR POINT IN |
C     |        |   |      |      |   | THE CODE IS FIRST PASS (.TRUE.) |
C     |        |   |      |      |   | OR LOOP BACK (.FALSE.) .        |
C     | BIGVWP | B | SCLR |  1   | L | INDICATES WHETHER THE LAST      |
C     |        |   |      |      |   | PLOTTING IN THE ZOOM PROCEDURE  |
C     |        |   |      |      |   | WAS AN INTEGRAL (.FALSE.) OR    |
C     |        |   |      |      |   | SPLIT GRAPH (.TRUE.) .          |
C     |   I    | I | SCLR |  1   | L | INDEX                           |
C     | ILEFT  | I | SCLR |  1   | L | ROUNDED LOWEST 2THETA VALUE     |
C     |        |   |      |      |   | USED FOR COMPUTING LPINC VALUE, |
C     |        |   |      |      |   | AND AS BOUND FOR ZOOMING RANGE. |
C     | IRIGHT | I | SCLR |  1   | L | ROUNDED HIGHEST 2THETA VALUE    |
C     |        |   |      |      |   | USED FOR COMPUTING LPINC VALUE, |
C     |        |   |      |      |   | AND AS BOUND FOR ZOOMING RANGE. |
C     |  ITOP  | I | SCLR |  1   | L | ROUNDED HIGHEST INTENSITY FOUND |
C     |        |   |      |      |   | IN THE WHOLE PATTERN, USED AS A |
C     |        |   |      |      |   | BOUND FOR ZOOMING RANGE.        |
C     |  KEY   | C | SCLR |  1   | L | INPUT CHARACTER KEY STRUCK BY   |
C     |        |   |      |      |   | USER AS A RESPONSE TO A PROMPT. |
C     | KEYBRD | I | SCLR |  1   | L | UNIT NUMBER FOR TERMINAL        |
C     |        |   |      |      |   | KEYBOARD.                       |
C     | LPINC  | R | SCLR |  1   |A,L| LOOP INCREMENT USED TO OBTAIN   |
C     |        |   |      |      |   | THE DESIRED RESOLUTION WHEN     |
C     |        |   |      |      |   | PLOTTING ARRAYS.                |
C     |  NOPT  | I | SCLR |  1   | L | OPTION NUMBER WITHIN A MENU.    |
C     |   R    | I | ARR  | 8001 |A,F| RAW DATA INTENSITY VALUES.      |
C     | RESCL  | R | SCLR |  1   | A | RESCALING FACTOR. USED TO       |
C     |        |   |      |      |   | NORMALIZE DATA TO 1,000  IF ANY |
C     |        |   |      |      |   | POINT EXCEEDS THIS VALUE.       |
C     | SAMPLE | C | ARR  |  18  |A,F| IDENTIFICATION OF THE SAMPLE.   |
C     | SCREEN | I | SCLR |  1   | L | UNIT NUMBER FOR CRT TERMINAL    |
C     |        |   |      |      |   | SCREEN.                         |
C     |  STEP  | I | SCLR |  1   | L | WITHIN ZOOM OPTION, INDICATES   |
C     |        |   |      |      |   | WHETHER PROMPTING SHALL RESTART |
C     |        |   |      |      |   | FOR 2THETA OR INTENSITIES,      |
C     |        |   |      |      |   | AFTER AN ERROR HAS OCURRED.     |
C     | SUBINT | I | SCLR |  1   |A,L| NUMBER OF SUBINTERVALS IN       |
C     |        |   |      |      |   | 2-THETA AXIS OF THE GRAPH.      |
C     |  TEMP  | R | SCLR |  1   | L | TEMPORARY STORAGE.              |
C     | TICKS  | I | SCLR |  1   |A,L| NUMBER OF DIVISIONS IN 2THETA   |
C     |        |   |      |      |   | AXIS OF THE GRAPH.              |
C     |  TTC   | R | SCLR |  1   |A,L| STARTING ANGLE FOR THE WHOLE    |
C     |        |   |      |      |   | INTENSITIES DATA SET.           |
C     | XLEFT  | R | SCLR |  1   |A,F| LOWEST 2THETA VALUE TO BE       |
C     |        |   |      |      |   | INCLUDED IN THE WHOLE GRAPH.    |
C     |  XMAX  | R | SCLR |  1   |A,L| HIGHEST USER DEFINED 2THETA     |
C     |        |   |      |      |   | VALUE FOR INCLUSION IN THE ZOOM.|
C     |  XMIN  | R | SCLR |  1   |A,L| LOWEST USER DEFINED 2THETA      |
C     |        |   |      |      |   | VALUE FOR INCLUSION IN THE ZOOM.|
C     | XRIGHT | R | SCLR |  1   |A,F| HIGHEST 2THETA VALUE TO BE      |
C     |        |   |      |      |   | INCLUDED IN THE WHOLE GRAPH.    |
C     |  YBOT  | R | SCLR |  1   |A,F| LOWEST INTENSITY VALUE TO BE    |
C     |        |   |      |      |   | INCLUDED IN THE WHOLE GRAPH.    |
C     |  YMAX  | R | SCLR |  1   |A,L| HIGHEST USER DEFINED INTENSITY  |
C     |        |   |      |      |   | VALUE FOR INCLUSION IN THE ZOOM.|
C     |  YMIN  | R | SCLR |  1   |A,L| LOWEST USER DEFINED INTENSITY   |
C     |        |   |      |      |   | VALUE FOR INCLUSION IN THE ZOOM.|
C     |  YTOP  | R | SCLR |  1   |A,F| HIGHEST INTENSITY VALUE TO BE   |
C     |        |   |      |      |   | INCLUDED IN THE WHOLE GRAPH.    |
C     ==================================================================
C     ==================================================================
C     |                   SUBPROGRAMS CALLED                           |
C     |================================================================|
C     | CONVENTIONS:                                                   |
C     |   1.) TYPE:  F=FUNCTION,  S=SUBROUTINE                         |
C     |   2.) SCOPE:  L=LOCAL,  G=GLOBAL                               |
C     |----------------------------------------------------------------|
C     | NAME            |TYP|SCP| DESCRIPTION                          |
C     |-----------------|---|---|--------------------------------------|
C     | CLEAR_AREA      | S | G | REGIS-CLEARS THE SPECIFIED PORTION   |
C     |                 |   |   |       OF THE SCREEN.                 |
C     | CLEAR_SCREEN    | S | G | REGIS-CLEARS ALL GRAPHICS OBJECTS ON |
C     |                 |   |   |       THE SCREEN.                    |
C     | CLEAR_TEXT      | S | G | REGIS-CLEARS ALL REGULAR TEXT FROM   |
C     |                 |   |   |       THE SCREEN.                    |
C     | CLEAR_VIEWPORT  | S | G | REGIS-CLEARS ALL GRAPHICS OBJECTS    |
C     |                 |   |   |       FROM THE VIEWPORT.             |
C     | COPY_SCREEN     | S | G | REGIS-TRANSFERS THE GRAPHIC-SCREEN   |
C     |                 |   |   |       IMAGE TO A PRINTER.            |
C     | DATAPLOT        | S | L | SETS THE ARRAYS UP TO MATCH SCREEN   |
C     |                 |   |   | RESOLUTION AND CALLS "PLOT_DATA".    |
C     | DRAW_GRAPHPAPER | S | G | REGIS-ESTABLISHES THE TYPE OF GRAPH  |
C     |                 |   |   |       PAPER TO PLOT DATA ON.         |
C     | INIT_GRAPHICS   | S | G | REGIS-SETS ALL GRAPHIC ATTRIBUTES TO |
C     |                 |   |   |       THEIR DEFAULT VALUES.          |
C     | LABEL_NUMAXIS   | S | G | REGIS-LABELS GRAPHPAPER AXIS WITH    |
C     |                 |   |   |       NUMERICAL VALUES AND TITLE.    |
C     | LINETEXT        | S | G | REGIS-DISPLAY A TEXT STRING AT       |
C     |                 |   |   |       SPECIFIED ROW AND COLUMN.      |
C     | RATION          | S | L | ROUNDS 2THETA PLOTTING LIMITS TO     |
C     |                 |   |   | PRODUCE RATIONAL TICK MARKS, AND     |
C     |                 |   |   | COMPUTES NUMBER OF AXIS DIVISIONS.   |
C     | SET_DEVICE      | S | G | REGIS-ESTABLISHES THE TERMINAL TYPE. |
C     | SET_VIEWPORT    | S | G | REGIS-DEFINES PORTION OF THE SCREEN  |
C     |                 |   |   |       WHERE PICTURE IS DISPLAYED.    |
C     | TEXT_SCROLL     | S | G | REGIS-DEFINES AREA WHERE REGULAR     |
C     |                 |   |   |       TEXT IS DISPLAYED.             |
C     ==================================================================
C
C
C
C    
C
      INTEGER*2 R (8001), ILEFT, IRIGHT, STEP
      INTEGER SCREEN, SUBINT, TICKS, XPLOT
      REAL LPINC
      CHARACTER*1 KEY
      CHARACTER*18 SAMPLE
      LOGICAL BEGIN, BIGVWP
      PARAMETER (KEYBRD=5, SCREEN=6)
      DATA  BEGIN /.TRUE./, BIGVWP /.FALSE./, RESCL /1./,
     *      YBOT, YTOP /0., 0./
C         
C         +------------------------+
C         | INITIALIZING VARIABLES |
C         +------------------------+
C           
      ISTAT = LIB$SPAWN ('$ SET TERMINAL /NOWRAP')
      ISTAT = LIB$SPAWN ('$ @U$DISK1:[XRD]VT125')
      ILEFT = IFIX(XLEFT)
      IRIGHT = IFIX(XRIGHT)
      DO 10 I = 1, 8001
         IF (YTOP .LT. R(I)) YTOP = FLOAT(R(I))
   10 CONTINUE
      IF (AMOD((YTOP - YBOT), 5.) .NE. 0) 
     *   YTOP = YTOP + (5. - AMOD((YTOP - YBOT), 5.))
C
C         +---------------------------------------------------------+
C         | CHECKING WHETHER ANY POINT EXCEEDS 1,000. IF SO, THE    |
C         | DATA WILL BE MULTIPLIED BY "RESCL" BEFORE BEING PLOTTED,|
C         | IN ORDER TO NORMALIZE THE DATA-SETS TO 1,000. THIS IS   |
C         | INTENDED TO AVOID LABELS IN EXP. NOTATION IN THE GRAPH. |
C         +---------------------------------------------------------+
C
      IF (YTOP .GT. 1000.) THEN
         MAXINT = IFIX (YTOP)
         RESCL = 1000. / YTOP
         YTOP = 1000.
      ENDIF
C
C         +---------------------+
C         | INITIALIZING SCREEN |
C         +---------------------+
C
      ITOP = IFIX(YTOP)
      WRITE(SCREEN, 10000)
10000 FORMAT ('1','THIS IS THE GRAPHICAL EXAMINATION ROUTINE.',/,1X,
     *   'BEFORE YOU PROCEED, YOU MAY WANT TO SET YOUR MONITOR TO',/,1X,
     *   'LIGHT TEXT/DARK SCREEN FOR BETTER VISUALIZATION.',/,1X,
     *   'ENTER A <CR> WHEN READY TO CONTINUE.    ',$)
   20 READ (KEYBRD, 10100, END=30) KEY
10100 FORMAT (A)
10200    FORMAT (' ','PLEASE TRY AGAIN    ',$)
   30 CONTINUE
      IF (MAXINT .GT. ITOP) THEN
         WRITE (SCREEN, 10215) MAXINT
10215    FORMAT ('0','PLEASE NOTE: MAX. INTENSITY VALUE IN RAW-DATA PA',
     *      'TTERN =', I5,/,1X,12('-'),' THE DATA-SETS WILL BE NORMALI',
     *      'ZED TO 1,000, FOR GRAPHICAL',/,14X,'PRESENTATION PURPOSE',
     *      'S.')
      ELSE
         WRITE (SCREEN, 10230)
10230    FORMAT (4(/))
      ENDIF
   50 WRITE (SCREEN, 10300)
C
C         +--------------------------+
C         | DISPLAYING OPTIONS MENU  |
C         +--------------------------+
C
10300 FORMAT ('0','OPTIONS:  (1)  DISPLAY GRAPH FOR THE ',
     *   'WHOLE PATTERN')
      IF (.NOT. (BEGIN)) THEN
         WRITE (SCREEN, 10335)
10335    FORMAT (' ',T12,'(2)  MODIFY THE SCALE OF THE GRAPH',/,
     *      T12,'(3)  MAKE A HARD-COPY OF THE DISPLAY',T50,
     *      '-  OPTION NO. OR "Q" TO QUIT: ',$)
      ELSE
         WRITE (SCREEN, 10370)
10370    FORMAT (' ',T12,'(2)  MODIFY THE SCALE OF THE GRAPH',
     *      T50,'-  OPTION NO. OR "Q" TO QUIT: ',$)
      ENDIF
   60 READ (KEYBRD, 10100) KEY
      TYPE *,' '
      IF (KEY .EQ. '1') THEN
         GOTO 70
      ELSE
         IF (KEY .EQ. '2') THEN
            GOTO 80
         ELSE
            IF (KEY .EQ. '3') THEN
               GOTO 150
            ELSE
               IF ((KEY .EQ. 'Q') .OR. (KEY .EQ. 'q')) GOTO 160
               WRITE (SCREEN, 10200)
               GOTO 60
            ENDIF
         ENDIF
      ENDIF
   70 CONTINUE
      CALL SET_DEVICE ('VT125')
      CALL INIT_GRAPHICS
      CALL CLEAR_SCREEN
      CALL CLEAR_TEXT
      CALL TEXT_SCROLL (22, 24)
      CALL SET_VIEWPORT (0.0, 260.0, 767.0, 479.0)
C
C         +-----------------------------------+
C         | SETTING UP AXIS AND LABELING THEM |
C         +-----------------------------------+
C      
      XMIN = XLEFT
      XMAX = XMIN + (XRIGHT - XLEFT) / 2.
      DO 75 I = 1, 2
         CALL RATIOM (XMIN, XMAX, TICKS, SUBINT)
         IMIN = IFIX(XMIN)
         IMAX = IFIX(XMAX)
         IF ((XMAX - IMAX) .GT. 0.) IMAX = IMAX + 1
         ITOP = IFIX(YTOP)
         CALL DRAW_GRAPHPAPER ('LIN',TICKS,SUBINT,'LIN',5,2,'YELLOW')
         CALL LABEL_NUMAXIS ('XT','2THETA',XMIN, XMAX, .TRUE.)
         CALL LABEL_NUMAXIS ('YL','INTEN.', YBOT, YTOP, .TRUE.)
         CALL LINETEXT (11, 58, SAMPLE)
C
C         +-------------------------+
C         | PLOTTING RAW-DATA CURVE |
C         +-------------------------+
         LPINC = (IMAX - IMIN) * 0.02 / 14.
         CALL DATAPLOT (R,XMIN,XMAX,LPINC,YTOP,YBOT,'CYAN',TTC,RESCL)
         CALL SET_VIEWPORT (0.0, 40.0, 767.0, 259.0)
         XMIN = XMAX 
         XMAX = XRIGHT
   75 CONTINUE
      BEGIN = .FALSE.
      BIGVWP = .FALSE.
      STEP = 0
      GOTO 50
C
C
C         +-------------+
C         | ZOOM OPTION |
C         +-------------+
C
   80 CONTINUE
      IF (STEP .NE. 3) THEN
         CALL CLEAR_SCREEN
         CALL TEXT_SCROLL (20, 24)
      ENDIF
      IF (STEP .EQ. 0) THEN
         CALL CLEAR_AREA (0.0, 0.0, 767.0, 90.0)
      ELSE 
         IF (BIGVWP) THEN
            CALL CLEAR_AREA (0.0, 0.0, 767.0, 58.0)
         ELSE
            CALL CLEAR_AREA (0.0, 0.0, 767.0, 90.0)
         ENDIF
      ENDIF
      WRITE (SCREEN, 10550)
10550 FORMAT ('0')
C
C         +--------------------------+
C         | ACCEPTING 2-THETA LIMITS |
C         +--------------------------+
C
   90 WRITE (SCREEN, 10600) ILEFT, IRIGHT
10600 FORMAT ('0' , 'ENTER THE LOWEST 2THETA TO BE INCLUDED IN THE ENLAR
     *GEMENT',/,T10,'VALID RANGE: MIN = ',I3,' MAX = ',I3,'         ',$)
      READ (KEYBRD, *, END=90, ERR=90) XMIN
      IF ((XMIN .LT. ILEFT) .OR. (XMIN .GT. IRIGHT)) THEN
         WRITE (SCREEN, 10650)
10650    FORMAT (3(/),' ERROR: COORDINATE ENTERED IS OUTSIDE RANGE.',
     *   'PLEASE TRY AGAIN.')
         GOTO 90
      ENDIF
C
  100 WRITE (SCREEN, 10700) ILEFT, IRIGHT
10700 FORMAT ('0','ENTER THE HIGHEST 2THETA TO BE INCLUDED IN THE ENLARG
     *EMENT',/,T10,'VALID RANGE: MIN = ',I3,' MAX = ',I3,'         ',$)
      READ (KEYBRD, *, END=100, ERR=100) XMAX
      IF ((XMAX .LT. ILEFT) .OR. (XMAX .GT. IRIGHT)) THEN
         WRITE (SCREEN, 10650)
         GOTO 100
      ENDIF
      IF (XMIN .GE. XMAX) THEN
         WRITE (SCREEN, 11000)
         STEP = 1
         GOTO 130
      ENDIF
C
C         +----------------------------+
C         | ACCEPTING INTENSITY LIMITS |
C         +----------------------------+

  110 WRITE (SCREEN, 10800) ITOP
10800 FORMAT ('0','ENTER THE LOWEST INTENSITY TO BE INCLUDED IN THE ENLA
     *RGEMENT',/,T10,'VALID RANGE: MIN = 0   MAX = ',I4,'        ',$)
      READ (KEYBRD, *, END=110, ERR=110) YMIN
      IF ((YMIN .LT. 0.0) .OR. (YMIN .GT. ITOP)) THEN
         WRITE (SCREEN, 10650)
         GOTO 110
      ENDIF
C
  120 WRITE (SCREEN, 10900) ITOP
10900 FORMAT('0','ENTER THE HIGHEST INTENSITY TO BE INCLUDED IN THE ENLA
     *RGEMENT',/,T10,'VALID RANGE: MIN = 0   MAX = ',I4,'        ',$)
      READ (KEYBRD, *, END=120, ERR=120) YMAX
      IF ((YMAX .LT. 0.0) .OR. (YMAX .GT. ITOP)) THEN
         WRITE (SCREEN, 10650)
         GOTO 120
      ENDIF
      IF (YMAX .LE. YMIN) THEN
         WRITE (SCREEN, 11000)
         STEP = 2
11000    FORMAT ('0',3(/),' ERROR: LOWER VALUE SPECIFIED AS HIGHER THAN'
     *      ,' UPPER VALUE.',/,' PLEASE ENTER <CR> FOR NEW PROMPT FOR ',
     *      'COORDINATES OR "E" TO EXIT:   ',$)
         GOTO 130  
      ENDIF
C
C
C
      STEP = 3
      IF (BIGVWP) THEN
         WRITE (SCREEN, 11100) XMIN, XMAX, YMIN, YMAX
11100    FORMAT ('0', 'THE SELECTED PLOTTING LIMITS ARE:', /, T3,
     *      '2-THETA: ', F6.2, '  -  ', F6.2, T40, 'INTENSITY: ',
     *      F6.0, '  -  ', F6.0, /, 1X, 'ENTER A <CR> TO CONTINUE OR',
     *      '"E" TO EXIT THE ZOOM PROCEDURE:    ', $)
      ELSE
         WRITE (SCREEN, 11150) XMIN, XMAX, YMIN, YMAX
11150    FORMAT (///,' THE SELECTED PLOTTING LIMITS ARE:',/,4X,
     *      '2-THETA:    ',F6.2,'  -  ',F6.2,/,4X,'INTENSITY:  ',F6.0,
     *      '  -  ',F6.0,/,1X,'ENTER A <CR> TO CONTINUE OR "E" TO EXIT',
     *      ' THE ZOOM PROCEDURE:    ',$)
      ENDIF
  130 READ (KEYBRD, 10100, END=140) KEY
      IF ((KEY .EQ. 'Q') .OR. (KEY .EQ. 'q') .OR. (KEY .EQ. 'E')
     *   .OR. (KEY .EQ. 'e')) THEN
         WRITE (SCREEN, 11200)
11200    FORMAT (' ','EXITING ZOOM OPTION PROCEDURE')
         GOTO 50
      ENDIF
  140 GO TO (90, 110, 145), STEP
C         +----------------------------------------------------------+
C         | SETTING UP THE ARRAYS TO BE PLOTTED WITH MAXIMUM NUMBER  |
C         | OF POINTS THAT CAN BE RESOLVED AND WITH COORDINATES THAT |
C         | WILL PRODUCE RATIONAL TICK MARKS.                        |
C         +----------------------------------------------------------+
C
  145 IF ((XMAX - XMIN) .GT. 40.) THEN
  146    WRITE (SCREEN, 11250)
11250    FORMAT (///, 1X, 'DO YOU WANT THE PLOTTING TO BE DIVIDED ',
     *      'INTO TWO GRAPHS (D),', /, 6X, 'OR AS A SINGLE GRAPH ',
     *      '(S) ?   --   OPTION:   ', $)
         READ (KEYBRD, 10100) KEY
         IF ((KEY .EQ. 'D') .OR. (KEY .EQ. 'd')) THEN
            TEMP = XMAX
            XMAX = XMIN + (XMAX - XMIN) / 2.
            CALL CLEAR_TEXT
            CALL TEXT_SCROLL (22, 24)
            CALL SET_VIEWPORT (0.0, 260.0, 767.0, 479.0)
            DO 147 I = 1, 2
               CALL RATIOM (XMIN, XMAX, TICKS, SUBINT)
               IF (AMOD ((YMAX - YMIN), 5.) .NE. 0)
     *            YMAX = YMAX + (5. - AMOD ((YMAX - YMIN), 5.))
               IMIN = IFIX (XMIN)
               IMAX = IFIX (XMAX)
               IF ((XMAX - IMAX) .GT. 0.) IMAX = IMAX + 1
               CALL DRAW_GRAPHPAPER ('LIN', TICKS, SUBINT, 'LIN', 
     *            5, 2, 'YELLOW')
               CALL LABEL_NUMAXIS ('XT', '2THETA', XMIN, XMAX, .TRUE.)
               CALL LABEL_NUMAXIS ('YL', 'INTEN.', YMIN, YMAX,.TRUE.)
               CALL LINETEXT (11, 58, SAMPLE)
               LPINC = (IMAX - IMIN) * 0.02 / 14.
               CALL DATAPLOT (R, XMIN, XMAX, LPINC, YMAX, YMIN, 'CYAN',
     *            TTC, RESCL)
               CALL SET_VIEWPORT (0.0, 40.0, 767.0, 259.0)
               XMIN = XMAX
               XMAX = TEMP
  147       CONTINUE
            BEGIN = .FALSE.
            BIGVWP = .TRUE.
            GO TO 50
         ELSE
            IF ((KEY .NE. 'S') .AND. (KEY .NE. 's')) THEN
               WRITE (SCREEN, 10200)
               GO TO 146
            ENDIF
         ENDIF
      ENDIF

      CALL RATIOM (XMIN, XMAX, TICKS, SUBINT)
      IF (AMOD((YMAX - YMIN), 5.) .NE. 0)
     *   YMAX = YMAX + (5. - AMOD((YMAX - YMIN), 5.))
      IMIN = IFIX(XMIN) 
      IMAX = IFIX(XMAX)
      IF ((XMAX - IMAX) .GT. 0.) IMAX = IMAX + 1
      LPINC = (IMAX - IMIN) * 0.02 / 14.
C
C         +-----------------------------------------------+
C         | CLEARING GRAPHICS FROM THE SCREEN, SETTING UP |
C         | NEW AXIS AND LABELING THEM.                   |
C         +-----------------------------------------------+
C
      CALL CLEAR_TEXT
      CALL TEXT_SCROLL (20, 24)
      CALL SET_VIEWPORT (0.0, 60.0, 767.0, 479.0)
      CALL DRAW_GRAPHPAPER ('LIN', TICKS, SUBINT, 'LIN', 5, 2, 'YELLOW')
      CALL LABEL_NUMAXIS ('XT', '2THETA', XMIN, XMAX, .TRUE.)
      CALL LABEL_NUMAXIS ('YL', 'INTENSITY', YMIN, YMAX, .TRUE.)
      CALL LINETEXT (1, 58, SAMPLE)
C
C         +------------------------------------+
C         | PLOTTING THE DATA TO THE NEW SCALE |
C         +------------------------------------+
C
      CALL DATAPLOT (R,XMIN,XMAX,LPINC,YMAX,YMIN,'CYAN',TTC,RESCL)
C         +---------------------------+
C         | RESTARTING ZOOM PROCEDURE |
C         +---------------------------+
      BEGIN = .FALSE.
      BIGVWP = .FALSE.
      GOTO 50
C
C         +---------------------------+
C         | HARD-COPY PRINTING OPTION |
C         +---------------------------+
C                
  150 CONTINUE
      WRITE (SCREEN, 11300)
11300 FORMAT ('0','A HARD-COPY OF THE GRAPHICS IS BEING TRANSFERRED TO',
     *' YOUR LOCAL PRINTER')
      IKEY=LIB$WAIT(3.0)
D      IKEY=LIB$SPAWN ('$ WAIT 00:00:03')
      WRITE (SCREEN,11400)
11400 FORMAT(/////)
      CALL COPY_SCREEN
C         +------------------------------------+
C         | RESTARTING OPTIONS QUERY PROCEDURE |
C         +------------------------------------+
      GOTO 50
C           
C         +--------------------+
C         | EXITING SUBROUTINE |
C         +--------------------+
C            
  160 CALL CLEAR_SCREEN
      CALL CLEAR_TEXT
      CALL TEXT_SCROLL (1, 24)
      RETURN
      END
C
C
C
C     ******************************************************************
          SUBROUTINE DATAPLOT (ARG, XL, XR, LI, YT, YB, COLOR, T, RF)
C     ******************************************************************
C     *                                                                *
C     * THIS SUBROUTINE ASSIGNS THE VALUES TO BE PLOTTED TO THE X- AND *
C     * Y-ARRAYS, ACCORDING TO THE INCREMENT COMPUTED IN ORDER TO      *
C     * ACOMPLISH THE DESIRED RESOLUTION AND FAST OUTPUT OF THE        *
C     * GRAPHICS. AFTER THIS STEP, "DATAPLOT" INVOKES REGIS ROUTINE    *
C     * "PLOT_DATA" TO ACTUALLY PLOT THE DATA.                         *
C     *                                                                *
C     ******************************************************************
C
C
C     ==================================================================
C     |                  GLOSSARY OF VARIABLES                         |
C     |================================================================|
C     | CONVENTIONS:                                                   |
C     |   1.) TYPE:  B=BOOLEAN, C=CHARACTER, I=INTEGER, R=REAL         |
C     |   2.) STRUCTURE:  ARR=ARRAY, MTRX=MATRIX, SCLR=SCALAR          |
C     |   3.) SCOPE:  A=ACTUAL PAR., F=FORMAL PAR., G=GLOBAL, L=LOCAL  |
C     |----------------------------------------------------------------|
C     |  VAR   |TYP|STRCT | DIM  |SCP| DESCRIPTION                     |
C     |--------|---|------|------|---|---------------------------------|
C     |  ARG   | I | ARR  | 8001 | F | INTENSITY VALUES TO BE PLOTTED. |
C     |   C    | R | SCLR |   1  | L | X-VALUE COMPUTED AT EACH STEP   |
C     |        |   |      |      |   | OF THE LOOP.                    |
C     | COLOR  | C | ARR  |   5  | A | COLOR IN WHICH CURVE IS TO BE   |
C     |        |   |      |      |   | DRAWN.                          |
C     |   I    | I | SCLR |   1  | L | ROUNDED INCREMENT APPLIED TO    |
C     |        |   |      |      |   | THE "ARG" ARRAY SUBSCRIPT.      |
C     |   J    | I | SCLR |   1  | L | INDEX.                          |
C     |   LI   | R | SCLR |   1  | F | LOOP INCREMENT.                 |
C     |   OS   | I | SCLR |   1  | L | OFFSET.  ARRAY POSITION         |
C     |        |   |      |      |   | CORRESPONDING TO ANGLE IN "T".  |
C     |   RF   | R | SCLR |   1  | F | RESCALING FACTOR.               |
C     |  RINC  | R | SCLR |   1  | L | REAL INCREMENT APPLIED TO THE   |
C     |        |   |      |      |   | "ARG" ARRAY SUBSCRIPT.          |
C     |   T    | R | SCLR |   1  | F | 2THETA CONVERSION.              |
C     |   XL   | R | SCLR |   1  | F | LOWEST 2THETA VALUE TO BE       |
C     |        |   |      |      |   | INCLUDED IN THE GRAPH.          |
C     |  XPT   | R | ARR  |  700 |A,L| SELECTED 2THETA VALUES TO BE    |
C     |        |   |      |      |   | ACTUALLY PLOTTED.               |
C     |   XR   | R | SCLR |   1  | F | HIGHEST 2THETA VALUE TO BE      |
C     |        |   |      |      |   | INCLUDED IN THE GRAPH.          |
C     |   YB   | I | SCLR |   1  | F | LOWEST INTENSITY VALUE TO BE    |
C     |        |   |      |      |   | INCLUDED IN THE GRAPH.          |
C     |  YPT   | I | ARR  |  700 |A,L| SELECTED INTENSITY VALUES TO BE |
C     |        |   |      |      |   | ACTUALLY PLOTTED.               |
C     |   YT   | I | SCLR |   1  | F | HIGHEST INTENSITY VALUE TO BE   |
C     |        |   |      |      |   | INCLUDED IN THE GRAPH.          |
C     ==================================================================
C     ==================================================================
C     |                    SUBPROGRAM CALLED                           |
C     |================================================================|
C     | CONVENTIONS:                                                   |
C     |   1.) TYPE:  F=FUNCTION,  S=SUBROUTINE                         |
C     |   2.) SCOPE:  L=LOCAL,  G=GLOBAL                               |
C     |----------------------------------------------------------------|
C     | NAME            |TYP|SCP| DESCRIPTION                          |
C     |-----------------|---|---|--------------------------------------|
C     | PLOT_DATA       | S | G | REGIS-MAPS THE DATA ARRAYS INTO      |
C     |                 |   |   |       RECTANGULAR COORDINATES AND    |
C     |                 |   |   |       PLOTS THEM ON GRAPH PAPER.     |
C     ==================================================================
C
C
C
      DIMENSION XPT(701), YPT(701)
      INTEGER*2 ARG (8001), OS
      REAL LI
      CHARACTER*5 COLOR
C
      OS = T / 0.02
      J = 1
      DO 10 C = XL, XR, LI
         RINC = C / 0.02 + 1.
         IF ((RINC - IFIX(RINC)) .GT. 0.50) THEN
            I = RINC + 1
         ELSE
            I = RINC
         ENDIF
         XPT(J) = (I - 1) * 0.02 
         YPT(J) = ARG(I - OS) * RF
         IF (YPT(J) .GT. YT)  YPT(J) = YT
         IF (YPT(J) .LT. YB)  YPT(J) = YB
         J = J + 1
   10 CONTINUE
      CALL PLOT_DATA (700, XPT, YPT, 'L', COLOR,, 1, .FALSE., .FALSE.)
      RETURN
      END
C     ******************************************************************
              SUBROUTINE RATIOM (VALMIN, VALMAX, SPACES, SUBSPC)
C     ******************************************************************
C     *                                                                *
C     * THIS SUBROUTINE COMPUTES THE DIFFERENCE BETWEEN THE LOWER AND  *
C     * UPPER BOUND OF THE X-VALUES RANGE TO BE PLOTTED, AND FINDS THE *
C     * NUMBER OF DIVISION CELLS (BETWEEN 5 AND 10) THAT WILL YIELD    *
C     * RATIONAL NUMERIC LABELS FOR THE X-AXIS. THIS MAY REQUIRE       *
C     * ROUNDING THE BOUNDARIES TO THE CLOSEST VALUES THAT WILL YIELD  *
C     * SUCH LABELS, AND STILL COVER THE DESIRED RANGE.                *
C     *                                                                *
C     ******************************************************************
C
C
C     ==================================================================
C     |                  GLOSSARY OF VARIABLES                         |
C     |================================================================|
C     | CONVENTIONS:                                                   |
C     |   1.) TYPE:  B=BOOLEAN, C=CHARACTER, I=INTEGER, R=REAL         |
C     |   2.) STRUCTURE: ARR=ARRAY, MTRX=MATRIX, SCLR=SCALAR           |
C     |   3.) SCOPE:  A=ACTUAL PAR., F=FORMAL PAR., G=GLOBAL, L=LOCAL  |
C     |----------------------------------------------------------------|
C     |  VAR   |TYP|STRCT | DIM  |SCP| DESCRIPTION                     |
C     |--------|---|------|------|---|---------------------------------|
C     |  DIF   | R | SCLR |   1  | L | DIFFERENCE BETWEEN UPPER AND    |
C     |        |   |      |      |   | LOWER BOUND OF X-VALUES RANGE.  |
C     |  DIV   | R | SCLR |   1  | L | DIVISOR BETWEEN 1 AND 10.       |
C     |  IDIF  | I | SCLR |   1  | L | INTEGER DIFFERENCE BETWEEN      |
C     |        |   |      |      |   | ADJUSTED "VALMIN" AND "VALMAX". |
C     | IVMAX  | I | SCLR |   1  | L | INTEGER PART OF "VALMAX".       |
C     |  MULT  | R | SCLR |   1  | L | MULTIPLICATION FACTOR.          |
C     |  REM   | I | SCLR |   1  | L | REMAINDER OF THE DIVISION OF    |
C     |        |   |      |      |   | "DIF" BY "DIV".                 |
C     | SPACES | I | SCLR |   1  | F | NUMBER OF DIVISIONS FOR X-AXIS. |
C     | SUBSPC | I | SCLR |   1  | F | NUMBER OF SUBDIVISIONS FOR      |
C     |        |   |      |      |   | X-AXIS.                         |
C     | VALMAX | R | SCLR |   1  | F | HIGHEST X-VALUE TO BE INCLUDED  |
C     |        |   |      |      |   | IN THE GRAPH.                   |
C     | VALMIN | R | SCLR |   1  | F | LOWEST X-VALUE TO BE INCLUDED   |
C     |        |   |      |      |   | IN THE GRAPH.                   |
C     ==================================================================
C
C
C
      INTEGER REM, SPACES, SUBSPC
      REAL MULT

      DIF = VALMAX - VALMIN
      IF (DIF .LT. 10.0) THEN
         IF (DIF .LE. 1.0) MULT = 0.1
         IF ((DIF .GT. 1.0) .AND. (DIF .LE. 2.0)) MULT = 0.2
         IF ((DIF .GT. 2.0) .AND. (DIF .LE. 5.0)) MULT = 0.5
         IF ((DIF .GT. 5.0) .AND. (DIF .LE. 10.0)) MULT = 1.0
         VALMAX = VALMIN + MULT * 10.
         SPACES = 10
      ELSE
         IF (DIF .GT. 10.0) THEN
            IVMAX = IFIX(VALMAX)
            IF ((VALMAX - IVMAX) .GT. 0) VALMAX = IVMAX + 1
            VALMIN = FLOAT(IFIX(VALMIN))
            DIF = VALMAX - VALMIN
   10       CONTINUE
               DIV = 10
   20          CONTINUE
                  REM = AMOD(DIF, DIV)
                  DIV = DIV - 1
               IF (REM .NE. 0) GOTO 20
            IF ((DIV + 1) .LE. 4) THEN
               VALMAX = VALMAX + 1
               DIF = DIF + 1
               GOTO 10
            ENDIF
            SPACES = DIV + 1
         ELSE
            SPACES = 10
         ENDIF
      ENDIF
      IDIF = IFIX (VALMAX - VALMIN)
      IF (IDIF .LE. 10) THEN
         SUBSPC = IDIF
      ELSE
         SUBSPC = IDIF / SPACES
      ENDIF
      RETURN
      END
